@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOL:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:1) */
+/* BOOL:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:1) */
 void
 bus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -64,9 +64,9 @@ bus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                                             guint        arg_2,
                                                             guint        arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -93,7 +93,7 @@ bus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* OBJECT:STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:2) */
+/* OBJECT:STRING (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:2) */
 void
 bus_marshal_OBJECT__STRING (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -105,9 +105,9 @@ bus_marshal_OBJECT__STRING (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_OBJECT__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -132,7 +132,7 @@ bus_marshal_OBJECT__STRING (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* VOID:INT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:3) */
+/* VOID:INT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:3) */
 void
 bus_marshal_VOID__INT_UINT (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -145,9 +145,9 @@ bus_marshal_VOID__INT_UINT (GClosure     *closure,
                                                gint         arg_1,
                                                guint        arg_2,
                                                gpointer     data2);
-  register GMarshalFunc_VOID__INT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -169,7 +169,7 @@ bus_marshal_VOID__INT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,INT,INT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:4) */
+/* VOID:INT,INT,INT,INT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:4) */
 void
 bus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -184,9 +184,9 @@ bus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                       gint         arg_3,
                                                       gint         arg_4,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -210,9 +210,9 @@ bus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:5) */
+/* VOID:OBJECT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:5) */
 
-/* VOID:OBJECT,BOOLEAN (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:6) */
+/* VOID:OBJECT,BOOLEAN (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:6) */
 void
 bus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -225,9 +225,9 @@ bus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -249,7 +249,7 @@ bus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:7) */
+/* VOID:OBJECT,STRING (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:7) */
 void
 bus_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -262,9 +262,9 @@ bus_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -286,7 +286,7 @@ bus_marshal_VOID__OBJECT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,BOOLEAN (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:8) */
+/* VOID:OBJECT,UINT,BOOLEAN (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:8) */
 void
 bus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -300,9 +300,9 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                                           guint        arg_2,
                                                           gboolean     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -325,7 +325,7 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,BOOLEAN,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:9) */
+/* VOID:OBJECT,UINT,BOOLEAN,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:9) */
 void
 bus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                             GValue       *return_value G_GNUC_UNUSED,
@@ -340,9 +340,9 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                                                gboolean     arg_3,
                                                                guint        arg_4,
                                                                gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -366,7 +366,7 @@ bus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING,STRING,STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:10) */
+/* VOID:OBJECT,STRING,STRING,STRING (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:10) */
 void
 bus_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure     *closure,
                                                GValue       *return_value G_GNUC_UNUSED,
@@ -381,9 +381,9 @@ bus_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure     *closure,
                                                                   gpointer     arg_3,
                                                                   gpointer     arg_4,
                                                                   gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -407,9 +407,9 @@ bus_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:11) */
+/* VOID:STRING (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:11) */
 
-/* VOID:STRING,INT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:12) */
+/* VOID:STRING,INT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:12) */
 void
 bus_marshal_VOID__STRING_INT (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -422,9 +422,9 @@ bus_marshal_VOID__STRING_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -446,7 +446,7 @@ bus_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:13) */
+/* VOID:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:13) */
 void
 bus_marshal_VOID__UINT_UINT (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -459,9 +459,9 @@ bus_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                 guint        arg_1,
                                                 guint        arg_2,
                                                 gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -483,7 +483,7 @@ bus_marshal_VOID__UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:14) */
+/* VOID:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:14) */
 void
 bus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -497,9 +497,9 @@ bus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                      guint        arg_2,
                                                      guint        arg_3,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -522,5 +522,5 @@ bus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/bus/marshalers.list:15) */
+/* VOID:VOID (/usr/src/ports/ibus/ibus-1.5.13-1.i686/src/ibus-1.5.13/bus/marshalers.list:15) */
 
