@@ -50,15 +50,15 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:NONE (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:1) */
+/* VOID:NONE (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:1) */
 
-/* VOID:OBJECT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:2) */
+/* VOID:OBJECT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:2) */
 
-/* VOID:POINTER (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:3) */
+/* VOID:POINTER (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:3) */
 
-/* VOID:STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:4) */
+/* VOID:STRING (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:4) */
 
-/* VOID:STRING,INT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:5) */
+/* VOID:STRING,INT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:5) */
 void
 _ibus_marshal_VOID__STRING_INT (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -71,9 +71,9 @@ _ibus_marshal_VOID__STRING_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -95,7 +95,7 @@ _ibus_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:6) */
+/* VOID:STRING,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:6) */
 void
 _ibus_marshal_VOID__STRING_UINT (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -108,9 +108,9 @@ _ibus_marshal_VOID__STRING_UINT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   guint        arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__STRING_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -132,7 +132,7 @@ _ibus_marshal_VOID__STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* BOOL:POINTER (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:7) */
+/* BOOL:POINTER (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:7) */
 void
 _ibus_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -144,9 +144,9 @@ _ibus_marshal_BOOLEAN__POINTER (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
                                                      gpointer     arg_1,
                                                      gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -171,7 +171,7 @@ _ibus_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:POINTER,POINTER (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:8) */
+/* BOOL:POINTER,POINTER (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:8) */
 void
 _ibus_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -184,9 +184,9 @@ _ibus_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
                                                              gpointer     arg_1,
                                                              gpointer     arg_2,
                                                              gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -212,7 +212,7 @@ _ibus_marshal_BOOLEAN__POINTER_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:9) */
+/* BOOL:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:9) */
 void
 _ibus_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -225,9 +225,9 @@ _ibus_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
                                                        guint        arg_1,
                                                        guint        arg_2,
                                                        gpointer     data2);
-  register GMarshalFunc_BOOLEAN__UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -253,7 +253,7 @@ _ibus_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:10) */
+/* BOOL:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:10) */
 void
 _ibus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                        GValue       *return_value G_GNUC_UNUSED,
@@ -267,9 +267,9 @@ _ibus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
                                                             guint        arg_2,
                                                             guint        arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -296,7 +296,7 @@ _ibus_marshal_BOOLEAN__UINT_UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOL:ULONG (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:11) */
+/* BOOL:ULONG (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:11) */
 void
 _ibus_marshal_BOOLEAN__ULONG (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -308,9 +308,9 @@ _ibus_marshal_BOOLEAN__ULONG (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__ULONG) (gpointer     data1,
                                                    gulong       arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__ULONG callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__ULONG callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -335,7 +335,7 @@ _ibus_marshal_BOOLEAN__ULONG (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:INT,INT,INT,INT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:12) */
+/* VOID:INT,INT,INT,INT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:12) */
 void
 _ibus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -350,9 +350,9 @@ _ibus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                       gint         arg_3,
                                                       gint         arg_4,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT_INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -376,7 +376,7 @@ _ibus_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:13) */
+/* VOID:UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:13) */
 void
 _ibus_marshal_VOID__UINT_UINT (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -389,9 +389,9 @@ _ibus_marshal_VOID__UINT_UINT (GClosure     *closure,
                                                 guint        arg_1,
                                                 guint        arg_2,
                                                 gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -413,7 +413,7 @@ _ibus_marshal_VOID__UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:14) */
+/* VOID:INT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:14) */
 void
 _ibus_marshal_VOID__INT_UINT (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -426,9 +426,9 @@ _ibus_marshal_VOID__INT_UINT (GClosure     *closure,
                                                gint         arg_1,
                                                guint        arg_2,
                                                gpointer     data2);
-  register GMarshalFunc_VOID__INT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -450,7 +450,7 @@ _ibus_marshal_VOID__INT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:15) */
+/* VOID:UINT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:15) */
 void
 _ibus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -464,9 +464,9 @@ _ibus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                      guint        arg_2,
                                                      guint        arg_3,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -489,7 +489,7 @@ _ibus_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,BOOL (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:16) */
+/* VOID:OBJECT,UINT,BOOL (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:16) */
 void
 _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                          GValue       *return_value G_GNUC_UNUSED,
@@ -503,9 +503,9 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
                                                           guint        arg_2,
                                                           gboolean     arg_3,
                                                           gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -528,7 +528,7 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,BOOL,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:17) */
+/* VOID:OBJECT,UINT,BOOL,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:17) */
 void
 _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -543,9 +543,9 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
                                                                gboolean     arg_3,
                                                                guint        arg_4,
                                                                gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_BOOLEAN_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -569,7 +569,7 @@ _ibus_marshal_VOID__OBJECT_UINT_BOOLEAN_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:18) */
+/* VOID:OBJECT,UINT,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:18) */
 void
 _ibus_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                       GValue       *return_value G_GNUC_UNUSED,
@@ -583,9 +583,9 @@ _ibus_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
                                                        guint        arg_2,
                                                        guint        arg_3,
                                                        gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -608,7 +608,7 @@ _ibus_marshal_VOID__OBJECT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOL (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:19) */
+/* VOID:OBJECT,BOOL (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:19) */
 void
 _ibus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                     GValue       *return_value G_GNUC_UNUSED,
@@ -621,9 +621,9 @@ _ibus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -645,7 +645,7 @@ _ibus_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOOL (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:20) */
+/* VOID:BOXED,BOOL (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:20) */
 void
 _ibus_marshal_VOID__BOXED_BOOLEAN (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -658,9 +658,9 @@ _ibus_marshal_VOID__BOXED_BOOLEAN (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gboolean     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__BOXED_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOXED_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -682,9 +682,9 @@ _ibus_marshal_VOID__BOXED_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:21) */
+/* VOID:BOXED (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:21) */
 
-/* VOID:STRING,STRING,VARIANT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:22) */
+/* VOID:STRING,STRING,VARIANT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:22) */
 void
 _ibus_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
                                            GValue       *return_value G_GNUC_UNUSED,
@@ -698,9 +698,9 @@ _ibus_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
                                                             gpointer     arg_2,
                                                             gpointer     arg_3,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_VARIANT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_VARIANT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -723,7 +723,7 @@ _ibus_marshal_VOID__STRING_STRING_VARIANT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:23) */
+/* VOID:STRING,STRING,STRING (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:23) */
 void
 _ibus_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                           GValue       *return_value G_GNUC_UNUSED,
@@ -737,9 +737,9 @@ _ibus_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                            gpointer     arg_2,
                                                            gpointer     arg_3,
                                                            gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -762,11 +762,11 @@ _ibus_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:24) */
+/* VOID:UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:24) */
 
-/* VOID:UINT,POINTER (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:25) */
+/* VOID:UINT,POINTER (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:25) */
 
-/* VOID:POINTER,UINT (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:26) */
+/* VOID:POINTER,UINT (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:26) */
 void
 _ibus_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -779,9 +779,9 @@ _ibus_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                    gpointer     arg_1,
                                                    guint        arg_2,
                                                    gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -803,7 +803,7 @@ _ibus_marshal_VOID__POINTER_UINT (GClosure     *closure,
             data2);
 }
 
-/* OBJECT:STRING (/usr/src/ports/ibus/ibus-1.5.11-1.i686/src/ibus-1.5.11/src/ibusmarshalers.list:27) */
+/* OBJECT:STRING (/usr/src/ports/ibus/ibus-1.5.13-1.x86_64/src/ibus-1.5.13/src/ibusmarshalers.list:27) */
 void
 _ibus_marshal_OBJECT__STRING (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -815,9 +815,9 @@ _ibus_marshal_OBJECT__STRING (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__STRING) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_OBJECT__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
