@@ -1,8 +1,8 @@
 /* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
- * Copyright (c) 2009-2013 Google Inc. All rights reserved.
- * Copyright (C) 2010-2013 Peng Huang <shawn.p.huang@gmail.com>
+ * Copyright (c) 2009-2014 Google Inc. All rights reserved.
+ * Copyright (C) 2010-2014 Peng Huang <shawn.p.huang@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,7 @@ enum {
     REGISTER_PROPERTIES,
     UPDATE_PROPERTY,
     SET_CURSOR_LOCATION,
+    SET_CURSOR_LOCATION_RELATIVE,
     CURSOR_UP_LOOKUP_TABLE,
     CURSOR_DOWN_LOOKUP_TABLE,
     HIDE_AUXILIARY_TEXT,
@@ -49,6 +50,7 @@ enum {
     START_SETUP,
     STATE_CHANGED,
     DESTROY_CONTEXT,
+    SET_CONTENT_TYPE,
     LAST_SIGNAL,
 };
 
@@ -117,6 +119,12 @@ static void      ibus_panel_service_set_cursor_location
                                     gint                    y,
                                     gint                    w,
                                     gint                    h);
+static void      ibus_panel_service_set_cursor_location_relative
+                                   (IBusPanelService       *panel,
+                                    gint                    x,
+                                    gint                    y,
+                                    gint                    w,
+                                    gint                    h);
 static void      ibus_panel_service_update_auxiliary_text
                                    (IBusPanelService       *panel,
                                     IBusText               *text,
@@ -133,6 +141,10 @@ static void      ibus_panel_service_update_preedit_text
 static void      ibus_panel_service_update_property
                                    (IBusPanelService       *panel,
                                     IBusProperty           *prop);
+static void      ibus_panel_service_set_content_type
+                                   (IBusPanelService       *panel,
+                                    guint                   purpose,
+                                    guint                   hints);
 
 G_DEFINE_TYPE (IBusPanelService, ibus_panel_service, IBUS_TYPE_SERVICE)
 
@@ -184,11 +196,21 @@ static const gchar introspection_xml[] =
     "      <arg direction='in' type='i' name='w' />"
     "      <arg direction='in' type='i' name='h' />"
     "    </method>"
+    "    <method name='SetCursorLocationRelative'>"
+    "      <arg direction='in' type='i' name='x' />"
+    "      <arg direction='in' type='i' name='y' />"
+    "      <arg direction='in' type='i' name='w' />"
+    "      <arg direction='in' type='i' name='h' />"
+    "    </method>"
     "    <method name='Reset' />"
     "    <method name='StartSetup' />"
     "    <method name='StateChanged' />"
     "    <method name='HideLanguageBar' />"
     "    <method name='ShowLanguageBar' />"
+    "    <method name='ContentType'>"
+    "      <arg direction='in'  type='u' name='purpose' />"
+    "      <arg direction='in'  type='u' name='hints' />"
+    "    </method>"
     /* Signals */
     "    <signal name='CursorUp' />"
     "    <signal name='CursorDown' />"
@@ -242,10 +264,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
     class->destroy_context       = ibus_panel_service_destroy_context;
     class->register_properties   = ibus_panel_service_register_properties;
     class->set_cursor_location   = ibus_panel_service_set_cursor_location;
+    class->set_cursor_location_relative = ibus_panel_service_set_cursor_location_relative;
     class->update_lookup_table   = ibus_panel_service_update_lookup_table;
     class->update_auxiliary_text = ibus_panel_service_update_auxiliary_text;
     class->update_preedit_text   = ibus_panel_service_update_preedit_text;
     class->update_property       = ibus_panel_service_update_property;
+    class->set_content_type      = ibus_panel_service_set_content_type;
 
     class->cursor_down_lookup_table = ibus_panel_service_not_implemented;
     class->cursor_up_lookup_table   = ibus_panel_service_not_implemented;
@@ -266,12 +290,14 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
     /* install signals */
     /**
      * IBusPanelService::update-preedit-text:
+     * @panel: An #IBusPanelService
      * @text: A preedit text to be updated.
      * @cursor_pos: The cursor position of the text.
      * @visible: Whether the update is visible.
      *
-     * Emitted when the client application get the update-preedit-text.
-     * Implement the member function update_preedit_text() in extended class
+     * Emitted when the client application get the ::update-preedit-text.
+     * Implement the member function
+     * IBusPanelServiceClass::update_preedit_text in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -292,11 +318,13 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::update-auxiliary-text:
+     * @panel: An #IBusPanelService
      * @text: A preedit text to be updated.
      * @visible: Whether the update is visible.
      *
-     * Emitted when the client application get the update-auxiliary-text.
-     * Implement the member function update_auxiliary_text() in extended class
+     * Emitted when the client application get the ::update-auxiliary-text.
+     * Implement the member function
+     * IBusPanelServiceClass::update_auxiliary_text in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -316,11 +344,13 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::update-lookup-table:
+     * @panel: An #IBusPanelService
      * @lookup_table: A lookup table to be updated.
      * @visible: Whether the update is visible.
      *
-     * Emitted when the client application get the update-lookup-table.
-     * Implement the member function update_lookup_table() in extended class
+     * Emitted when the client application get the ::update-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::update_lookup_table in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -340,10 +370,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::focus-in:
+     * @panel: An #IBusPanelService
      * @input_context_path: Object path of InputContext.
      *
-     * Emitted when the client application get the focus-in.
-     * Implement the member function focus_in() in extended class to receive
+     * Emitted when the client application get the ::focus-in.
+     * Implement the member function
+     * IBusPanelServiceClass::focus_in in extended class to receive
      * this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -362,10 +394,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::focus-out:
+     * @panel: An #IBusPanelService
      * @input_context_path: Object path of InputContext.
      *
-     * Emitted when the client application get the focus-out.
-     * Implement the member function focus_out() in extended class to receive
+     * Emitted when the client application get the ::focus-out.
+     * Implement the member function
+     * IBusPanelServiceClass::focus_out in extended class to receive
      * this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -384,10 +418,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::register-properties:
+     * @panel: An #IBusPanelService
      * @prop_list: An IBusPropList that contains properties.
      *
-     * Emitted when the client application get the register-properties.
-     * Implement the member function register_properties() in extended class
+     * Emitted when the client application get the ::register-properties.
+     * Implement the member function
+     * IBusPanelServiceClass::register_properties in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -406,10 +442,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::update-property:
+     * @panel: An #IBusPanelService
      * @prop: The IBusProperty to be updated.
      *
-     * Emitted when the client application get the update-property.
-     * Implement the member function update_property() in extended class to
+     * Emitted when the client application get the ::update-property.
+     * Implement the member function
+     * IBusPanelServiceClass::update_property in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -428,13 +466,15 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::set-cursor-location:
+     * @panel: An #IBusPanelService
      * @x: X coordinate of the cursor.
      * @y: Y coordinate of the cursor.
      * @w: Width of the cursor.
      * @h: Height of the cursor.
      *
-     * Emitted when the client application get the set-cursor-location.
-     * Implement the member function set_cursor_location() in extended class
+     * Emitted when the client application get the ::set-cursor-location.
+     * Implement the member function
+     * IBusPanelServiceClass::set_cursor_location in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -455,10 +495,41 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
             G_TYPE_INT);
 
     /**
-     * IBusPanelService::cursor-up-lookup-table:
+     * IBusPanelService::set-cursor-location-relative:
+     * @panel: An #IBusPanelService
+     * @x: X coordinate of the cursor.
+     * @y: Y coordinate of the cursor.
+     * @w: Width of the cursor.
+     * @h: Height of the cursor.
      *
-     * Emitted when the client application get the cursor-up-lookup-table.
-     * Implement the member function cursor_up_lookup_table() in extended
+     * Emitted when the client application get the set-cursor-location-relative.
+     * Implement the member function set_cursor_location_relative() in
+     * extended class to receive this signal.
+     *
+     * <note><para>Argument @user_data is ignored in this function.</para>
+     * </note>
+     */
+    panel_signals[SET_CURSOR_LOCATION_RELATIVE] =
+        g_signal_new (I_("set-cursor-location-relative"),
+            G_TYPE_FROM_CLASS (gobject_class),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (IBusPanelServiceClass, set_cursor_location_relative),
+            NULL, NULL,
+            _ibus_marshal_VOID__INT_INT_INT_INT,
+            G_TYPE_NONE,
+            4,
+            G_TYPE_INT,
+            G_TYPE_INT,
+            G_TYPE_INT,
+            G_TYPE_INT);
+
+    /**
+     * IBusPanelService::cursor-up-lookup-table:
+     * @panel: An #IBusPanelService
+     *
+     * Emitted when the client application get the ::cursor-up-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::cursor_up_lookup_table in extended
      * class to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -475,9 +546,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::cursor-down-lookup-table:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the cursor-down-lookup-table.
-     * Implement the member function cursor_down_lookup_table() in extended
+     * Emitted when the client application get the ::cursor-down-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::cursor_down_lookup_table in extended
      * class to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -494,9 +567,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::hide-auxiliary-text:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the hide-auxiliary-text.
-     * Implement the member function hide_auxiliary_text() in extended class
+     * Emitted when the client application get the ::hide-auxiliary-text.
+     * Implement the member function
+     * IBusPanelServiceClass::hide_auxiliary_text in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -513,9 +588,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::hide-language-bar:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the hide-language-bar.
-     * Implement the member function hide_language_bar() in extended class to
+     * Emitted when the client application get the ::hide-language-bar.
+     * Implement the member function
+     * IBusPanelServiceClass::hide_language_bar in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -532,9 +609,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::hide-lookup-table:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the hide-lookup-table.
-     * Implement the member function hide_lookup_table() in extended class to
+     * Emitted when the client application get the ::hide-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::hide_lookup_table in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -551,9 +630,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::hide-preedit-text:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the hide-preedit-text.
-     * Implement the member function hide_preedit_text() in extended class to
+     * Emitted when the client application get the ::hide-preedit-text.
+     * Implement the member function
+     * IBusPanelServiceClass::hide_preedit_text in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -570,9 +651,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::page-up-lookup-table:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the page-up-lookup-table.
-     * Implement the member function page_up_lookup_table() in extended class
+     * Emitted when the client application get the ::page-up-lookup-table.
+     * Implement the member function 
+     * IBusPanelServiceClass::page_up_lookup_table in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -589,9 +672,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::page-down-lookup-table:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the page-down-lookup-table.
-     * Implement the member function page_down_lookup_table() in extended
+     * Emitted when the client application get the ::page-down-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::page_down_lookup_table in extended
      * class to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -608,9 +693,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::reset:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the reset.
-     * Implement the member function reset() in extended class to receive this
+     * Emitted when the client application get the ::reset.
+     * Implement the member function
+     * IBusPanelServiceClass::reset in extended class to receive this
      * signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -627,9 +714,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::show-auxiliary-text:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the show-auxiliary-text.
-     * Implement the member function show_auxiliary_text() in extended class
+     * Emitted when the client application get the ::show-auxiliary-text.
+     * Implement the member function
+     * IBusPanelServiceClass::show_auxiliary_text in extended class
      * to receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -646,9 +735,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::show-language-bar:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the show-language-bar.
-     * Implement the member function show_language_bar() in extended class to
+     * Emitted when the client application get the ::show-language-bar.
+     * Implement the member function
+     * IBusPanelServiceClass::show_language_bar in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -665,9 +756,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::show-lookup-table:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the show-lookup-table.
-     * Implement the member function show_lookup_table() in extended class to
+     * Emitted when the client application get the ::show-lookup-table.
+     * Implement the member function
+     * IBusPanelServiceClass::show_lookup_table in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -684,9 +777,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::show-preedit-text:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the show-preedit-text.
-     * Implement the member function show_preedit_text() in extended class to
+     * Emitted when the client application get the ::show-preedit-text.
+     * Implement the member function
+     * IBusPanelServiceClass::show_preedit_text in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -703,9 +798,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::start-setup:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the start-setup.
-     * Implement the member function start_setup() in extended class to
+     * Emitted when the client application get the ::start-setup.
+     * Implement the member function
+     * IBusPanelServiceClass::start_setup in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -722,9 +819,11 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::state-changed:
+     * @panel: An #IBusPanelService
      *
-     * Emitted when the client application get the state-changed.
-     * Implement the member function state_changed() in extended class to
+     * Emitted when the client application get the ::state-changed.
+     * Implement the member function
+     * IBusPanelServiceClass::state_changed in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -741,10 +840,12 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
 
     /**
      * IBusPanelService::destroy-context:
+     * @panel: An #IBusPanelService
      * @input_context_path: Object path of InputContext.
      *
      * Emitted when the client application destroys.
-     * Implement the member function destroy_context() in extended class to
+     * Implement the member function
+     * IBusPanelServiceClass::destroy_context in extended class to
      * receive this signal.
      *
      * <note><para>Argument @user_data is ignored in this function.</para>
@@ -760,6 +861,32 @@ ibus_panel_service_class_init (IBusPanelServiceClass *class)
             G_TYPE_NONE,
             1,
             G_TYPE_STRING);
+
+    /**
+     * IBusPanelService::set-content-type:
+     * @panel: An #IBusPanelService
+     * @purpose: Input purpose.
+     * @hints: Input hints.
+     *
+     * Emitted when the client application get the ::set-content-type.
+     * Implement the member function
+     * IBusPanelServiceClass::set_content_type in extended class to
+     * receive this signal.
+     *
+     * <note><para>Argument @user_data is ignored in this function.</para>
+     * </note>
+     */
+    panel_signals[SET_CONTENT_TYPE] =
+        g_signal_new (I_("set-content-type"),
+            G_TYPE_FROM_CLASS (gobject_class),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (IBusPanelServiceClass, set_content_type),
+            NULL, NULL,
+            _ibus_marshal_VOID__UINT_UINT,
+            G_TYPE_NONE,
+            2,
+            G_TYPE_UINT,
+            G_TYPE_UINT);
 }
 
 static void
@@ -927,6 +1054,24 @@ ibus_panel_service_service_method_call (IBusService           *service,
         return;
     }
 
+    if (g_strcmp0 (method_name, "SetCursorLocationRelative") == 0) {
+        gint x, y, w, h;
+        g_variant_get (parameters, "(iiii)", &x, &y, &w, &h);
+        g_signal_emit (panel, panel_signals[SET_CURSOR_LOCATION_RELATIVE],
+                       0, x, y, w, h);
+        g_dbus_method_invocation_return_value (invocation, NULL);
+        return;
+    }
+
+    if (g_strcmp0 (method_name, "ContentType") == 0) {
+        guint purpose, hints;
+        g_variant_get (parameters, "(uu)", &purpose, &hints);
+        g_signal_emit (panel, panel_signals[SET_CONTENT_TYPE], 0,
+                       purpose, hints);
+        g_dbus_method_invocation_return_value (invocation, NULL);
+        return;
+    }
+
     const static struct {
         const gchar *name;
         const gint signal_id;
@@ -1048,6 +1193,16 @@ ibus_panel_service_set_cursor_location (IBusPanelService *panel,
     ibus_panel_service_not_implemented(panel);
 }
 
+static void
+ibus_panel_service_set_cursor_location_relative (IBusPanelService *panel,
+                                                 gint              x,
+                                                 gint              y,
+                                                 gint              w,
+                                                 gint              h)
+{
+    ibus_panel_service_not_implemented(panel);
+}
+
 static void
 ibus_panel_service_update_auxiliary_text (IBusPanelService *panel,
                                           IBusText         *text,
@@ -1080,6 +1235,14 @@ ibus_panel_service_update_property (IBusPanelService *panel,
     ibus_panel_service_not_implemented(panel);
 }
 
+static void
+ibus_panel_service_set_content_type (IBusPanelService *panel,
+                                     guint             purpose,
+                                     guint             hints)
+{
+    ibus_panel_service_not_implemented(panel);
+}
+
 IBusPanelService *
 ibus_panel_service_new (GDBusConnection *connection)
 {
